@@ -1,14 +1,14 @@
 ## File Name: mice_multilevel_add_groupmeans.R
-## File Version: 0.12
+## File Version: 0.13
 
 
 mice_multilevel_add_groupmeans <- function( y, ry, x, type,
-        groupcenter.slope, type3=3, type4=4, aggr_label="M._" ){
+        groupcenter.slope, type3=3, type4=4, aggr_label="M._" )
+{
     #----
     # type 3: group means should be included
     # type 4: group means and random slopes should be included
     #----
-
     # add groupmeans in the regression model
     if ( any( type %in% c( type3, type4) ) ){
         x0 <- as.matrix(cbind( x[,type==-2], x[,type %in% c(type3, type4)] ))
