@@ -1,15 +1,16 @@
 ## File Name: with.mids.1chain.R
-## File Version: 0.05
+## File Version: 0.07
 
 
 #******************************************************************************
 # with function for objects of class mids
-with.mids.1chain <- function(data, expr, ...) {
+with.mids.1chain <- function(data, expr, ...)
+{
     # adapted from with.mids.1chain
     call <- match.call()
     if (class(data) !="mids.1chain"){
         stop("The data must have class mids.1chain")
-                                    }
+    }
     data <- data$midsobj
     #-----------------------------
     # original code from with.mids from mice package
@@ -20,14 +21,13 @@ with.mids.1chain <- function(data, expr, ...) {
         analyses[[i]] <- eval( expr=substitute(expr), envir=data.i,
                     enclos=parent.frame())
         if (is.expression(analyses[[i]])){
-            analyses[[i]] <- eval(expr=analyses[[i]],
+        analyses[[i]] <- eval(expr=analyses[[i]],
                         envir=data.i, enclos=parent.frame())
-                                        }
+        }
     }
     # return the complete data analyses as a list of length nimp
     object <- list(call=call, call1=data$call, nmis=data$nmis, analyses=analyses)
     oldClass(object) <- c("mira", "matrix")
-    #    class(object) <- "mira"
     return(object)
 }
 #******************************************************************************
